pub struct ScriptBuf<T>(/* private fields */);Expand description
An owned, growable script.
ScriptBuf is the most common script type that has the ownership over the contents of the
script. It has a close relationship with its borrowed counterpart, Script.
Just as other similar types, this implements Deref, so deref coercions apply. Also note
that all the safety/validity restrictions that apply to Script apply to ScriptBuf as well.
Hexadecimal strings
Scripts are consensus encoded with a length prefix and as a result of this in some places in the
ecosystem one will encounter hex strings that include the prefix while in other places the
prefix is excluded. To support parsing and formatting scripts as hex we provide a bunch of
different APIs and trait implementations. Please see [examples/script.rs] for a thorough
example of all the APIs.
Panics
ScriptBuf is backed by Vec and inherits its panic behavior. This means that attempting to
construct scripts larger than isize::MAX bytes will panic.
Implementations
Sourceimpl<T> ScriptBuf<T>
impl<T> ScriptBuf<T>
Sourcepub const fn from_bytes(bytes: Vec<u8>) -> Self
pub const fn from_bytes(bytes: Vec<u8>) -> Self
Converts byte vector into script.
This method doesn’t (re)allocate. bytes is just the script bytes not consensus
encoding (i.e no length prefix).
Sourcepub fn from_hex_prefixed(s: &str) -> Result<Self, FromHexError>
pub fn from_hex_prefixed(s: &str) -> Result<Self, FromHexError>
Sourcepub fn from_hex_no_length_prefix(
s: &str,
) -> Result<Self, DecodeVariableLengthBytesError>
pub fn from_hex_no_length_prefix( s: &str, ) -> Result<Self, DecodeVariableLengthBytesError>
Constructs a new ScriptBuf from a hex string.
This is not consensus encoding. If your hex string is a consensus encoded script
then use ScriptBuf::from_hex_prefixed.
There is no script decoding error path because what ever is in the hex input string is assumed to be the script. This means if you pass a consensus encoded hex string into this function there will be no error and the script will not be what you expect.
Errors
Errors if s cannot be parsed into a vector.
Sourcepub fn as_mut_script(&mut self) -> &mut Script<T>
pub fn as_mut_script(&mut self) -> &mut Script<T>
Returns a mutable reference to unsized script.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Converts the script into a byte vector.
This method doesn’t (re)allocate.
Returns
Just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn into_boxed_script(self) -> Box<Script<T>>
pub fn into_boxed_script(self) -> Box<Script<T>>
Converts this ScriptBuf into a boxed Script.
This method reallocates if the capacity is greater than length of the script but should not
when they are equal. If you know beforehand that you need to create a script of exact size
use reserve_exact before adding data to the script so that the
reallocation can be avoided.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Constructs a new empty script with at least the specified capacity.
Sourcepub fn reserve(&mut self, additional_len: usize)
pub fn reserve(&mut self, additional_len: usize)
Pre-allocates at least additional_len bytes if needed.
Reserves capacity for at least additional_len more bytes to be inserted in the given
script. The script may reserve more space to speculatively avoid frequent reallocations.
After calling reserve, capacity will be greater than or equal to
self.len() + additional_len. Does nothing if capacity is already sufficient.
Panics
Panics if the new capacity exceeds isize::MAX bytes.
Sourcepub fn reserve_exact(&mut self, additional_len: usize)
pub fn reserve_exact(&mut self, additional_len: usize)
Pre-allocates exactly additional_len bytes if needed.
Unlike reserve, this will not deliberately over-allocate to speculatively avoid frequent
allocations. After calling reserve_exact, capacity will be greater than or equal to
self.len() + additional. Does nothing if the capacity is already sufficient.
Note that the allocator may give the collection more space than it requests. Therefore,
capacity cannot be relied upon to be precisely minimal. Prefer reserve
if future insertions are expected.
Panics
Panics if the new capacity exceeds isize::MAX bytes.
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of bytes available for writing without reallocation.
It is guaranteed that script.capacity() >= script.len() always holds.
Sourcepub fn reserved_len_for_slice(len: usize) -> usize
pub fn reserved_len_for_slice(len: usize) -> usize
Returns the encoded length for pushing a slice of bytes.
Sourcepub fn push_opcode(&mut self, opcode: Opcode)
pub fn push_opcode(&mut self, opcode: Opcode)
Adds a single opcode to the script.
Sourcepub fn push_int(&mut self, n: i32) -> Result<(), Error>
pub fn push_int(&mut self, n: i32) -> Result<(), Error>
Adds instructions to push an integer onto the stack.
Errors
Returns Error::NumericOverflow when n is outside the minimally encodable range.
Sourcepub fn push_int_unchecked(&mut self, n: i64)
pub fn push_int_unchecked(&mut self, n: i64)
Adds instructions to push an unchecked integer onto the stack.
Sourcepub fn push_int_non_minimal(&mut self, data: i64)
pub fn push_int_non_minimal(&mut self, data: i64)
Adds instructions to push an integer without numeric-opcode optimization.
Panics
Panics only if the internally encoded script integer somehow exceeds the PushBytes limit.
Sourcepub fn push_slice<D: AsRef<[u8]>>(&mut self, data: D)
pub fn push_slice<D: AsRef<[u8]>>(&mut self, data: D)
Adds instructions to push some arbitrary data onto the stack.
Sourcepub fn push_slice_non_minimal<D: AsRef<[u8]>>(&mut self, data: D)
pub fn push_slice_non_minimal<D: AsRef<[u8]>>(&mut self, data: D)
Adds instructions to push arbitrary data without minimal-push optimization.
Panics
Panics only if data exceeds the maximum size supported by PushBytes.
Sourcepub fn push_instruction(&mut self, instruction: Instruction<'_>)
pub fn push_instruction(&mut self, instruction: Instruction<'_>)
Adds a single instruction.
Sourcepub fn scan_and_push_verify(&mut self)
pub fn scan_and_push_verify(&mut self)
Adds an OP_VERIFY or rewrites the last opcode to its VERIFY form when possible.
Methods from Deref<Target = Script<T>>
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
pub fn as_bytes(&self) -> &[u8] ⓘ
Returns the script data as a byte slice.
This is just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
Returns the script data as a mutable byte slice.
This is just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn to_vec(&self) -> Vec<u8> ⓘ
pub fn to_vec(&self) -> Vec<u8> ⓘ
Returns a copy of the script data.
This is just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn to_hex_string_prefixed(&self) -> String
pub fn to_hex_string_prefixed(&self) -> String
Consensus encodes the script as lower-case hex.
Consensus encoding includes a length prefix. To hex encode without the length prefix use
to_hex_string_no_length_prefix.
Sourcepub fn to_hex_string_no_length_prefix(&self) -> String
pub fn to_hex_string_no_length_prefix(&self) -> String
Encodes the script as lower-case hex.
This is not consensus encoding. The returned hex string will not include the length
prefix. See to_hex_string_prefixed.
Sourcepub fn instructions(&self) -> Instructions<'_> ⓘ
pub fn instructions(&self) -> Instructions<'_> ⓘ
Iterates over decoded instructions.
Sourcepub fn instructions_minimal(&self) -> Instructions<'_> ⓘ
pub fn instructions_minimal(&self) -> Instructions<'_> ⓘ
Iterates over decoded instructions while enforcing minimal pushes.
Sourcepub fn count_sigops(&self) -> usize
pub fn count_sigops(&self) -> usize
Counts signature-check operations using accurate multisig counting.
This is the counting mode used by the node for redeem scripts and
witness scripts. OP_CHECKSIGADD is not counted by Tidecoin consensus.
Sourcepub fn count_sigops_legacy(&self) -> usize
pub fn count_sigops_legacy(&self) -> usize
Counts signature-check operations using legacy multisig counting.
This is the counting mode used by the node for scriptSigs and scriptPubKeys in context-free block sanity checks.
Sourcepub fn instruction_indices(&self) -> InstructionIndices<'_> ⓘ
pub fn instruction_indices(&self) -> InstructionIndices<'_> ⓘ
Iterates over decoded instructions together with their byte indices.
Sourcepub fn instruction_indices_minimal(&self) -> InstructionIndices<'_> ⓘ
pub fn instruction_indices_minimal(&self) -> InstructionIndices<'_> ⓘ
Iterates over decoded instructions and indices while enforcing minimal pushes.
Sourcepub fn last_opcode(&self) -> Option<Opcode>
pub fn last_opcode(&self) -> Option<Opcode>
Returns the last opcode if the final instruction is an opcode.
Sourcepub fn last_pushdata(&self) -> Option<&PushBytes>
pub fn last_pushdata(&self) -> Option<&PushBytes>
Returns the last pushed byte slice if the final instruction is a data push.