pub struct ScriptHash(/* private fields */);Expand description
A 160-bit hash of Tidecoin script bytecode.
Implementations
Sourceimpl ScriptHash
impl ScriptHash
Sourcepub fn from_script<T>(
redeem_script: &Script<T>,
) -> Result<Self, RedeemScriptSizeError>where
T: ScriptHashableTag,
pub fn from_script<T>(
redeem_script: &Script<T>,
) -> Result<Self, RedeemScriptSizeError>where
T: ScriptHashableTag,
Constructs a new ScriptHash after first checking the script size.
520-byte limitation on serialized script size
Tidecoin P2SH evaluation hashes the serialized script and then pushes that script onto the stack for execution, so the serialized script is subject to the same rules as any other PUSHDATA operation. No pushed data item may exceed 520 bytes, so a P2SH output cannot be spent if the redemption script it refers to is larger than 520 bytes.
Errors
Returns an error if the script exceeds 520 bytes.
Sourcepub fn from_script_unchecked<T>(script: &Script<T>) -> Self
pub fn from_script_unchecked<T>(script: &Script<T>) -> Self
Constructs a new ScriptHash from any script irrespective of script size.
If you hash a script that exceeds 520 bytes in size and use it to create a P2SH output then the output will be unspendable.
impl ScriptHash
impl ScriptHash
pub const fn from_byte_array(bytes: [u8; 20]) -> Self
pub const fn from_byte_array(bytes: [u8; 20]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 20]
pub const fn to_byte_array(self) -> [u8; 20]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 20]
pub const fn as_byte_array(&self) -> &[u8; 20]
Returns a reference to the underlying byte array.