pub struct WScriptHash(/* private fields */);Expand description
SegWit (256-bit) version of a Tidecoin script bytecode hash.
Implementations
Sourceimpl WScriptHash
impl WScriptHash
Sourcepub fn from_script(
witness_script: &WitnessScript,
) -> Result<Self, WitnessScriptSizeError>
pub fn from_script( witness_script: &WitnessScript, ) -> Result<Self, WitnessScriptSizeError>
Constructs a new WScriptHash after first checking the script size.
10,000-byte limit on the witness script
The witnessScript (≤ 10,000 bytes) is popped off the initial witness stack. SHA256 of the witnessScript must match the 32-byte witness program.
Errors
Returns an error if the script exceeds 10,000 bytes.
Sourcepub fn from_script_unchecked(script: &WitnessScript) -> Self
pub fn from_script_unchecked(script: &WitnessScript) -> Self
Constructs a new WScriptHash from any script irrespective of script size.
If you hash a script that exceeds 10,000 bytes in size and use it to create a Segwit output then the output will be unspendable.
impl WScriptHash
impl WScriptHash
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 32]
pub const fn to_byte_array(self) -> [u8; 32]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 32]
pub const fn as_byte_array(&self) -> &[u8; 32]
Returns a reference to the underlying byte array.