Tidecoin scripts.
Structs
- Builder
- Script builder.
- Instruction
Indices - Iterator over script instructions with byte offsets.
- Instructions
- Iterator over parsed script instructions.
- Parsed
Witness Program - Parsed witness-program view over a scriptPubKey byte slice.
- Push
Bytes - Byte slices that can be pushed into script.
- Push
Bytes Buf - Owned script-push bytes.
- Push
Bytes Error - Error constructing script push bytes.
- Redeem
Script Size Error - Error while hashing a redeem script.
- Script
- Tidecoin script slice.
- Script
Buf - An owned, growable script.
- Script
BufDecoder - The decoder for the
ScriptBuftype. - Script
BufDecoder Error - An error consensus decoding a
ScriptBuf<T>. - Script
Encoder - The encoder for the
Script<T>type. - Script
Hash - A 160-bit hash of Tidecoin script bytecode.
- WScript
Hash - SegWit (256-bit) version of a Tidecoin script bytecode hash.
- Witness
Script Size Error - Error while hashing a witness script.
Enums
- Error
- Basic script decoding/building errors.
- Instruction
- Parsed script instruction.
- Redeem
Script Tag - A P2SH redeem script.
- Script
IntError - Possible errors that can arise from reading a script integer.
- Script
PubKey Tag - A script public key (scriptPubKey).
- Script
SigTag - A script signature (scriptSig).
- Witness
Program Class - Primitive witness-program class independent of consensus activation flags.
- Witness
Program Error - Witness-program shape error.
- Witness
Script Tag - A Segwit v0 witness script.
Constants
- MAX_
REDEEM_ SCRIPT_ SIZE - The maximum allowed redeem script size for a P2SH output.
- MAX_
WITNESS_ SCRIPT_ SIZE - The maximum allowed redeem script size of the witness script.
- P2A_
PROGRAM - The Tidecoin pay-to-anchor witness-v1 program.
- SCRIPTNUM_
CLTV_ MAX_ LEN - Extended script-number byte limit used by lock-time related opcodes.
- SCRIPTNUM_
STANDARD_ MAX_ LEN - Standard script-number byte limit used by arithmetic and most script opcodes.
- WITNESS_
PROGRAM_ MAX_ SIZE - Maximum byte size of a witness program.
- WITNESS_
PROGRAM_ MIN_ SIZE - Minimum byte size of a witness program.
Traits
- Script
Hashable Tag - Either a redeem script or a Segwit version 0 scriptpubkey.
- Tag
- Sealed trait representing a type of script.
Functions
- encode_
scriptnum - Encodes an integer in script number format into a freshly allocated buffer.
- is_
minimally_ encoded_ scriptnum - Returns whether a script-number byte slice uses minimal encoding for the provided bound.
- read_
scriptbool - Decodes a script truth value.
- read_
scriptint_ non_ minimal - Decodes a script integer without enforcing minimal encoding.
- read_
scriptnum - Decodes a script number with caller-selected minimal-encoding and length rules.
- validate_
witness_ program - Validates address/output-level witness-program length rules.
- write_
scriptint - Encodes an integer in script number format.
Type Aliases
- Redeem
Script - A reference to a P2SH redeem script.
- Redeem
Script Buf - A P2SH redeem script.
- Script
PubKey - A reference to a
scriptPubKey(locking script). - Script
PubKey Buf - A
scriptPubKey(locking script). - Script
PubKey BufDecoder - A
scriptPubKeydecoder. - Script
Sig - A reference to a script signature (scriptSig).
- Script
SigBuf - A script signature (scriptSig).
- Script
SigBuf Decoder - A
scriptSigdecoder. - Witness
Script - A reference to a Segwit v0 witness script.
- Witness
Script Buf - A Segwit v0 witness script.